==> moodle-1.4.3-pgsql.tgz: moodle/lang/ca/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.5 unstable development (2004083000)


$string['addanewdiscussion'] = 'Afegeix un nou tema de debat';
$string['addanewtopic'] = 'Afegeix un nou tema';
$string['allowchoice'] = 'Permet triar a tothom';
$string['allowdiscussions'] = 'Pot un $a enviar un missatge a aquest frum?';
$string['allowratings'] = 'Permeteu valorar els missatges?';
$string['allowsdiscussions'] = 'Aquest frum permet iniciar a tothom un tema de debat.';
$string['anyfile'] = 'Qualsevol fitxer';
$string['attachment'] = 'Fitxer adjunt';
$string['bynameondate'] = 'per $a->name - $a->date';
$string['configdisplaymode'] = 'El mode de visualitzaci per defecte dels debats si no se n\'especifica un.';
$string['configenablerssfeeds'] = 'Aquest commutador habilitar la possibilitat de tenir RSS en tots els frums. Haureu d\'activar l\'RSS en els parmetres de cada frum.';
$string['configlongpost'] = 'Qualsevol missatge per damunt d\'aquesta mida (excls l\'HTML) es considera massa llarg.';
$string['configmanydiscussions'] = 'Nombre mxim de debats per pgina';
$string['configmaxbytes'] = 'Mida mxima per defecte per a tots els fitxers adjuntats als frums d\'aquest lloc (subjecte als lmits de cada curs i altres parmetres locals)';
$string['configreplytouser'] = 'Quan s\'envia per correu un missatge d\'un frum, ha de portar l\'adrea de l\'usuari com a remitent de manera que els destinataris puguin contestar-li privadament per correu? Encara que s\'especifiqui aix, els usuaris poden triar en el seu perfil de mantenir oculta l\'adrea de correu.';
$string['configshortpost'] = 'Qualsevol missatge per sota d\'aquesta mida (excls l\'HTML) es considera massa breu.';
$string['couldnotadd'] = 'Un error desconegut ha impedit afegir el vostre missatge';
$string['couldnotdeleteratings'] = 'No es pot suprimir perqu ja l\'han valorat altres persones';
$string['couldnotdeletereplies'] = 'No es pot suprimir perqu ja l\'han contestat altres persones';
$string['couldnotupdate'] = 'Un error desconegut ha impedit actualitzar el vostre missatge';
$string['delete'] = 'Suprimeix';
$string['deleteddiscussion'] = 'El tema de debat s\'ha suprimit';
$string['deletedpost'] = 'El missatge s\'ha suprimit';
$string['deletesure'] = 'Segur que voleu suprimir aquest missatge?';
$string['digestmailheader'] = 'Aquest s el vostre resum diari de missatges enviats als frums de $a->sitename. Si voleu canviar les vostres preferncies de correu dels frums, aneu a $a->userprefs.';
$string['digestmailprefs'] = 'el vostre perfil d\'usuari';
$string['digestmailsubject'] = 'Resum diari de missatges $a';
$string['digestsentusers'] = 'S\'han enviat amb xit els resums de correu de: $a usuaris.';
$string['discussion'] = 'Debat';
$string['discussionmoved'] = 'Aquest debat s\'ha traslladat a \'$a\'.';
$string['discussionname'] = 'Ttol del debat';
$string['discussions'] = 'Debats';
$string['discussionsstartedby'] = 'Debats iniciats per $a';
$string['discussionsstartedbyrecent'] = 'Debats iniciats recentment per $a';
$string['discussthistopic'] = 'Debat aquest tema';
$string['eachuserforum'] = 'Cada persona inicia un debat';
$string['edit'] = 'Edita';
$string['editing'] = 'S\'est editant';
$string['emptymessage'] = 'El vostre missatge presentava algun problema. Potser l\'haveu deixat en blanc, o el fitxer adjunt era massa gran. Els canvis NO s\'han desat.';
$string['everyonecanchoose'] = 'Cadasc pot triar subscriure\'s';
$string['everyoneissubscribed'] = 'Tothom est subscrit a aquest frum';
$string['existingsubscribers'] = 'Subscriptors actuals';
$string['forcesubscribe'] = 'Imposa que tothom estigui subscrit';
$string['forcesubscribeq'] = 'Imposeu que tothom estigui subscrit?';
$string['forum'] = 'Frum';
$string['forumintro'] = 'Introducci al frum';
$string['forumname'] = 'Nom del frum';
$string['forums'] = 'Frums';
$string['forumtype'] = 'Tipus de frum';
$string['generalforum'] = 'Frum estndard per a s general';
$string['generalforums'] = 'Frums generals';
$string['inforum'] = 'en $a';
$string['intronews'] = 'Anuncis i notcies generals';
$string['introsocial'] = 'Un frum obert per xerrar sobre qualsevol cosa que es vulgui';
$string['introteacher'] = 'Un frum per a notes i debats noms del professorat';
$string['lastpost'] = 'Darrer missatge';
$string['learningforums'] = 'Frums d\'aprenentatge';
$string['maxattachmentsize'] = 'Mida mxima dels fitxers adjunts';
$string['maxtimehaspassed'] = 'Ha passat el temps mxim per editar aquest missatge! ($a)';
$string['message'] = 'Missatge';
$string['modeflatnewestfirst'] = 'Visualitza les respostes, comenant per la ms recent';
$string['modeflatoldestfirst'] = 'Visualitza les respostes, comenant per la ms antiga';
$string['modenested'] = 'Visualitza les respostes escalonades';
$string['modethreaded'] = 'Visualitza les respostes abreujades, seguint el fil de la discussi';
$string['modulename'] = 'Frum';
$string['modulenameplural'] = 'Frums';
$string['more'] = 'ms';
$string['movethisdiscussionto'] = 'Trasllada aquest debat a... ';
$string['namenews'] = 'Frum de notcies';
$string['namesocial'] = 'Frum social';
$string['nameteacher'] = 'Frum del professorat';
$string['newforumposts'] = 'Nous missatges dels frums';
$string['nodiscussions'] = 'Encara no hi ha cap tema de debat en aquest frum';
$string['noguestpost'] = 'Els usuaris visitants no poden enviar missatges';
$string['nomorepostscontaining'] = 'No s\'han trobat ms missatges que continguin \'$a\'';
$string['nonews'] = 'Encara no s\'han enviat notcies';
$string['noposts'] = 'No hi ha missatges';
$string['nopostscontaining'] = 'No s\'ha trobat cap missatge que contingui \'$a\'';
$string['nosubscribers'] = 'Encara no hi ha subscriptors d\'aquest frum';
$string['notingroup'] = 'Heu de ser part d\'un grup per veure aquest frum.';
$string['nownotsubscribed'] = '$a->name NO rebr cpies de \'$a->forum\' per correu electrnic.';
$string['nowsubscribed'] = '$a->name rebr cpies de \'$a->forum\' per correu electrnic.';
$string['numposts'] = '$a missatges';
$string['olderdiscussions'] = 'Debats anteriors';
$string['openmode0'] = 'Debats no, respostes no';
$string['openmode1'] = 'Debats no, per respostes s';
$string['openmode2'] = 'Debats i respostes s';
$string['parent'] = 'Mostra missatge original';
$string['parentofthispost'] = 'Missatge original';
$string['postadded'] = 'S\'ha afegit el vostre missatge. <P>Teniu $a per editar-lo si voleu fer algun canvi.';
$string['postincontext'] = 'Mostra aquest missatge en el seu context';
$string['postmailinfo'] = 'Aix s una cpia d\'un missatge enviat al lloc web $a.
Per afegir la vostra resposta via web, feu clic en aquest enlla:';
$string['postrating1'] = 'Sobretot coneixement separats';
$string['postrating2'] = 'Separats i connectats';
$string['postrating3'] = 'Sobretot coneixements connectats';
$string['posts'] = 'Missatges';
$string['posttoforum'] = 'Envia al frum';
$string['postupdated'] = 'S\'ha actualitzat el vostre missatge';
$string['potentialsubscribers'] = 'Subscriptors potencials';
$string['processingdigest'] = 'S\'est processant el resum de correu de l\'usuari $a';
$string['processingpost'] = 'S\'est processant el missatge $a';
$string['prune'] = 'Separa';
$string['prunedpost'] = 'S\'ha creat un nou debat amb aquest missatge';
$string['pruneheading'] = 'Separa el missatge i mou-lo a un altre debat';
$string['rate'] = 'Valora';
$string['rating'] = 'Valoraci';
$string['ratingeveryone'] = 'Qualsevol pot valorar els missatges';
$string['ratingno'] = 'Sense valorar';
$string['ratingonlyteachers'] = 'Noms els $a poden valorar els missatges';
$string['ratingpublic'] = 'Els $a poden veure les valoracions de tots';
$string['ratingpublicnot'] = 'Els $a noms poden veure les seves valoracions';
$string['ratings'] = 'Valoracions';
$string['ratingssaved'] = 'S\'han desat les valoracions';
$string['ratingsuse'] = 'Utilitza valoracions';
$string['ratingtime'] = 'Limita les valoracions als missatges enviats en aquestes dates:';
$string['re'] = 'Re:';
$string['readtherest'] = 'Mostra la resta d\'aquest tema';
$string['replies'] = 'Respostes';
$string['repliesmany'] = '$a respostes fins ara';
$string['repliesone'] = '$a resposta fins ara';
$string['reply'] = 'Contesta';
$string['replyforum'] = 'Contesta al frum';
$string['rsssubscriberssdiscussions'] = 'Visualitza l\'RSS dels debats \'$a\'';
$string['rsssubscriberssposts'] = 'Visualitza l\'RSS dels missatges \'$a\'';
$string['search'] = 'Cerca';
$string['searchforums'] = 'Cerca als frums';
$string['searcholderposts'] = 'Cerca missatges anteriors...';
$string['searchresults'] = 'Resultats de la recerca';
$string['sendinratings'] = 'Envia les meves darreres valoracions';
$string['showsubscribers'] = 'Mostra/edita els subscriptors';
$string['singleforum'] = 'Un debat simple';
$string['startedby'] = 'Iniciat per';
$string['subject'] = 'Assumpte';
$string['subscribe'] = 'Subscriu-me a aquest frum';
$string['subscribeall'] = 'Subscriu a tothom a aquest frum';
$string['subscribed'] = 'Subscrit';
$string['subscribenone'] = 'Cancella totes les subscripcions a aquest frum';
$string['subscribers'] = 'Subscriptors';
$string['subscribersto'] = 'Subscriptors de \'$a\'';
$string['subscribestart'] = 'Envia\'m cpia dels missatges d\'aquest frum per correu electrnic';
$string['subscribestop'] = 'No vull rebre cpies per correu dels missatges d\'aquest frum';
$string['subscription'] = 'Subscripci';
$string['subscriptions'] = 'Subscripcions';
$string['unsubscribe'] = 'Cancella la meva subscripci a aquest frum';
$string['unsubscribed'] = 'La vostra subscripci ha estat cancellada';
$string['unsubscribeshort'] = 'Cancella subscripci';
$string['yesforever'] = 'S, per sempre';
$string['yesinitially'] = 'S, inicialment';
$string['youratedthis'] = 'La vostra valoraci';
$string['yournewtopic'] = 'Nou tema de debat';
$string['yourreply'] = 'La vostra resposta';

?>

==> moodle-1.5-pgsql.tgz: moodle/lang/ca/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.5 ALPHA (2005042400)


$string['addanewdiscussion'] = 'Afegeix un nou tema de debat';
$string['addanewtopic'] = 'Afegeix un nou tema';
$string['advancedsearch'] = 'Cerca avanada';
$string['allforums'] = 'Tots els frums';
$string['allowchoice'] = 'Permet triar a tothom';
$string['allowdiscussions'] = 'Pot un $a enviar un missatge a aquest frum?';
$string['allowratings'] = 'Permeteu valorar els missatges?';
$string['allowsdiscussions'] = 'Aquest frum permet iniciar a tothom un tema de debat.';
$string['anyfile'] = 'Qualsevol fitxer';
$string['attachment'] = 'Fitxer adjunt';
$string['bynameondate'] = 'per $a->name - $a->date';
$string['configcleanreadtime'] = 'L\'hora del dia per a netejar missatges vells de la taula de lectures.';
$string['configdisplaymode'] = 'El mode de visualitzaci per defecte dels debats si no se n\'especifica un.';
$string['configenablerssfeeds'] = 'Aquest commutador habilitar la possibilitat de tenir RSS en tots els frums. Haureu d\'activar l\'RSS en els parmetres de cada frum.';
$string['configlongpost'] = 'Qualsevol missatge per damunt d\'aquesta mida (excls l\'HTML) es considera massa llarg.';
$string['configmanydiscussions'] = 'Nombre mxim de debats per pgina';
$string['configmaxbytes'] = 'Mida mxima per defecte per a tots els fitxers adjuntats als frums d\'aquest lloc (subjecte als lmits de cada curs i altres parmetres locals)';
$string['configoldpostdays'] = 'Nombre de dies per a considerar ja llegit qualsevol missatge.';
$string['configreplytouser'] = 'Quan s\'envia per correu un missatge d\'un frum, ha de portar l\'adrea de l\'usuari com a remitent de manera que els destinataris puguin contestar-li privadament per correu? Encara que s\'especifiqui aix, els usuaris poden triar en el seu perfil de mantenir oculta l\'adrea de correu.';
$string['configshortpost'] = 'Qualsevol missatge per sota d\'aquesta mida (excls l\'HTML) es considera massa breu.';
$string['configtrackreadposts'] = 'Poseu \'s\' per fer el seguiment dels missatges llegits/no llegits per cada usuari.';
$string['configusermarksread'] = '\'S\' vol dir que l\'usuari ha de marcar el missatge com a llegit. \'No\' vol dir que en llegir un missatge es marca automticament com a llegit.';
$string['couldnotadd'] = 'Un error desconegut ha impedit afegir el vostre missatge';
$string['couldnotdeleteratings'] = 'No es pot suprimir perqu ja l\'han valorat altres persones';
$string['couldnotdeletereplies'] = 'No es pot suprimir perqu ja l\'han contestat altres persones';
$string['couldnotupdate'] = 'Un error desconegut ha impedit actualitzar el vostre missatge';
$string['delete'] = 'Suprimeix';
$string['deleteddiscussion'] = 'El tema de debat s\'ha suprimit';
$string['deletedpost'] = 'El missatge s\'ha suprimit';
$string['deletedposts'] = 'Aquests missatges s\'han suprimit';
$string['deletesure'] = 'Segur que voleu suprimir aquest missatge?';
$string['deletesureplural'] = 'Segur que voleu suprimir aquest missatges i totes les seves respostes? ($a missatges)';
$string['digestmailheader'] = 'Aquest s el vostre resum diari de missatges enviats als frums de $a->sitename. Si voleu canviar les vostres preferncies de correu dels frums, aneu a $a->userprefs.';
$string['digestmailprefs'] = 'el vostre perfil d\'usuari';
$string['digestmailsubject'] = 'Resum diari de missatges $a';
$string['digestsentusers'] = 'S\'han enviat amb xit els resums de correu de: $a usuaris.';
$string['discussion'] = 'Debat';
$string['discussionmoved'] = 'Aquest debat s\'ha traslladat a \'$a\'.';
$string['discussionname'] = 'Ttol del debat';
$string['discussions'] = 'Debats';
$string['discussionsstartedby'] = 'Debats iniciats per $a';
$string['discussionsstartedbyrecent'] = 'Debats iniciats recentment per $a';
$string['discussthistopic'] = 'Debat aquest tema';
$string['eachuserforum'] = 'Cada persona inicia un debat';
$string['edit'] = 'Edita';
$string['editedby'] = 'Editat per $a->name - $a->date';
$string['editing'] = 'S\'est editant';
$string['emptymessage'] = 'El vostre missatge presentava algun problema. Potser l\'haveu deixat en blanc, o el fitxer adjunt era massa gran. Els canvis NO s\'han desat.';
$string['everyonecanchoose'] = 'Cadasc pot triar subscriure\'s';
$string['everyoneissubscribed'] = 'Tothom est subscrit a aquest frum';
$string['existingsubscribers'] = 'Subscriptors actuals';
$string['forcesubscribe'] = 'Imposa que tothom estigui subscrit';
$string['forcesubscribeq'] = 'Imposeu que tothom estigui subscrit?';
$string['forum'] = 'Frum';
$string['forumintro'] = 'Introducci al frum';
$string['forumname'] = 'Nom del frum';
$string['forumposts'] = 'Missatges del frum';
$string['forums'] = 'Frums';
$string['forumtype'] = 'Tipus de frum';
$string['generalforum'] = 'Frum estndard per a s general';
$string['generalforums'] = 'Frums generals';
$string['inforum'] = 'en $a';
$string['intronews'] = 'Anuncis i notcies generals';
$string['introsocial'] = 'Un frum obert per xerrar sobre qualsevol cosa que es vulgui';
$string['introteacher'] = 'Un frum per a notes i debats noms del professorat';
$string['lastpost'] = 'Darrer missatge';
$string['learningforums'] = 'Frums d\'aprenentatge';
$string['markalldread'] = 'Marca com a llegits tots els missatges d\'aquest debat.';
$string['markallread'] = 'Marca com a llegits tots els missatges d\'aquest frum.';
$string['markread'] = 'Marca com a llegit';
$string['markreadbutton'] = 'Marca<br />llegit';
$string['markunread'] = 'Marca com a no llegit';
$string['markunreadbutton'] = 'Marca<br />no llegit';
$string['maxattachmentsize'] = 'Mida mxima dels fitxers adjunts';
$string['maxtimehaspassed'] = 'Ha passat el temps mxim per editar aquest missatge! ($a)';
$string['message'] = 'Missatge';
$string['missingsearchterms'] = 'Els termes de cerca segents noms apareixen en les etiquetes HTML del missatge:';
$string['modeflatnewestfirst'] = 'Visualitza les respostes, comenant per la ms recent';
$string['modeflatoldestfirst'] = 'Visualitza les respostes, comenant per la ms antiga';
$string['modenested'] = 'Visualitza les respostes escalonades';
$string['modethreaded'] = 'Visualitza les respostes abreujades, seguint el fil de la discussi';
$string['modulename'] = 'Frum';
$string['modulenameplural'] = 'Frums';
$string['more'] = 'ms';
$string['movethisdiscussionto'] = 'Trasllada aquest debat a... ';
$string['namenews'] = 'Frum de notcies';
$string['namesocial'] = 'Frum social';
$string['nameteacher'] = 'Frum del professorat';
$string['newforumposts'] = 'Nous missatges dels frums';
$string['nodiscussions'] = 'Encara no hi ha cap tema de debat en aquest frum';
$string['noguestpost'] = 'Els visitants no poden enviar missatges.';
$string['noguestsubscribe'] = 'Els visitants no poden subscriure\'s per rebre els missatges del frum per correu electrnic.';
$string['noguesttracking'] = 'Els visitants no poden definir opcions de seguiment.';
$string['nomorepostscontaining'] = 'No s\'han trobat ms missatges que continguin \'$a\'';
$string['nonews'] = 'Encara no s\'han enviat notcies';
$string['noposts'] = 'No hi ha missatges';
$string['nopostscontaining'] = 'No s\'ha trobat cap missatge que contingui \'$a\'';
$string['nosubscribers'] = 'Encara no hi ha subscriptors d\'aquest frum';
$string['notingroup'] = 'Heu de ser part d\'un grup per veure aquest frum.';
$string['notrackforum'] = 'No facis el seguiment de missatges no llegits';
$string['nownotsubscribed'] = '$a->name NO rebr cpies de \'$a->forum\' per correu electrnic.';
$string['nownottracking'] = '$a->name ja no fa el seguiment del frum \'$a->forum\'.';
$string['nowsubscribed'] = '$a->name rebr cpies de \'$a->forum\' per correu electrnic.';
$string['nowtracking'] = '$a->name fa el seguiment del frum \'$a->forum\'.';
$string['numposts'] = '$a missatges';
$string['olderdiscussions'] = 'Debats anteriors';
$string['oldertopics'] = 'Temes anteriors';
$string['openmode0'] = 'Debats no, respostes no';
$string['openmode1'] = 'Debats no, per respostes s';
$string['openmode2'] = 'Debats i respostes s';
$string['parent'] = 'Mostra missatge original';
$string['parentofthispost'] = 'Missatge original';
$string['postadded'] = 'S\'ha afegit el vostre missatge. <p>Teniu $a per editar-lo si voleu fer algun canvi.';
$string['postincontext'] = 'Mostra aquest missatge en el seu context';
$string['postmailinfo'] = 'Aix s una cpia d\'un missatge enviat al lloc web $a.
Per afegir la vostra resposta via web, feu clic en aquest enlla:';
$string['postrating1'] = 'Sobretot coneixement separats';
$string['postrating2'] = 'Separats i connectats';
$string['postrating3'] = 'Sobretot coneixements connectats';
$string['posts'] = 'Missatges';
$string['posttoforum'] = 'Envia al frum';
$string['postupdated'] = 'S\'ha actualitzat el vostre missatge';
$string['potentialsubscribers'] = 'Subscriptors potencials';
$string['processingdigest'] = 'S\'est processant el resum de correu de l\'usuari $a';
$string['processingpost'] = 'S\'est processant el missatge $a';
$string['prune'] = 'Separa';
$string['prunedpost'] = 'S\'ha creat un nou debat amb aquest missatge';
$string['pruneheading'] = 'Separa el missatge i mou-lo a un altre debat';
$string['rate'] = 'Valora';
$string['rating'] = 'Valoraci';
$string['ratingeveryone'] = 'Qualsevol pot valorar els missatges';
$string['ratingno'] = 'Sense valorar';
$string['ratingonlyteachers'] = 'Noms els $a poden valorar els missatges';
$string['ratingpublic'] = 'Els $a poden veure les valoracions de tots';
$string['ratingpublicnot'] = 'Els $a noms poden veure les seves valoracions';
$string['ratings'] = 'Valoracions';
$string['ratingssaved'] = 'S\'han desat les valoracions';
$string['ratingsuse'] = 'Utilitza valoracions';
$string['ratingtime'] = 'Limita les valoracions als missatges enviats en aquestes dates:';
$string['re'] = 'Re:';
$string['readtherest'] = 'Mostra la resta d\'aquest tema';
$string['replies'] = 'Respostes';
$string['repliesmany'] = '$a respostes fins ara';
$string['repliesone'] = '$a resposta fins ara';
$string['reply'] = 'Contesta';
$string['replyforum'] = 'Contesta al frum';
$string['rsssubscriberssdiscussions'] = 'Visualitza l\'RSS dels debats \'$a\'';
$string['rsssubscriberssposts'] = 'Visualitza l\'RSS dels missatges \'$a\'';
$string['search'] = 'Cerca';
$string['searchdatefrom'] = 'Missatges posteriors a aquesta data';
$string['searchdateto'] = 'Missatges anteriors a aquesta data';
$string['searchforumintro'] = 'Introduu els termes de la cerca en els camps segents:';
$string['searchforums'] = 'Cerca als frums';
$string['searchfullwords'] = 'Aquests mots haurien d\'aparxer com a mots complets';
$string['searchnotwords'] = 'Aquests mots NO s\'hi haurien d\'incloure';
$string['searcholderposts'] = 'Cerca missatges anteriors...';
$string['searchphrase'] = 'Aquesta frase exacta ha d\'aparixer al missatge';
$string['searchresults'] = 'Resultats de la recerca';
$string['searchsubject'] = 'Aquests mots haurien de ser a l\'assumpte';
$string['searchuser'] = 'Aquest nom hauria de coincidir amb l\'autor';
$string['searchuserid'] = 'Moodle ID de l\'autor';
$string['searchwhichforums'] = 'Trieu quins frums voleu cercar';
$string['searchwords'] = 'Aquests mots poden aparixer en qualsevol part del missatge';
$string['seeallposts'] = 'Visualitza tots els missatges d\'aquest usuari';
$string['sendinratings'] = 'Envia les meves darreres valoracions';
$string['showsubscribers'] = 'Mostra/edita els subscriptors';
$string['singleforum'] = 'Un debat simple';
$string['startedby'] = 'Iniciat per';
$string['subject'] = 'Assumpte';
$string['subscribe'] = 'Subscriu-me a aquest frum';
$string['subscribeall'] = 'Subscriu a tothom a aquest frum';
$string['subscribed'] = 'Subscrit';
$string['subscribenone'] = 'Cancella totes les subscripcions a aquest frum';
$string['subscribers'] = 'Subscriptors';
$string['subscribersto'] = 'Subscriptors de \'$a\'';
$string['subscribestart'] = 'Envia\'m cpia dels missatges d\'aquest frum per correu electrnic';
$string['subscribestop'] = 'No vull rebre cpies per correu dels missatges d\'aquest frum';
$string['subscription'] = 'Subscripci';
$string['subscriptions'] = 'Subscripcions';
$string['trackforum'] = 'Fes el seguiments de missatges no llegits';
$string['tracking'] = 'Seguiment';
$string['trackingoff'] = 'Inactiu';
$string['trackingon'] = 'Actiu';
$string['trackingoptional'] = 'Opcional';
$string['trackingtype'] = 'Voleu fer el seguiment de missatges llegits en aquest frum?';
$string['unread'] = 'No llegit';
$string['unreadposts'] = 'Missatges no llegits';
$string['unreadpostsnumber'] = '$a missatges no llegits';
$string['unreadpostsone'] = '1 missatge no llegit';
$string['unsubscribe'] = 'Cancella la meva subscripci a aquest frum';
$string['unsubscribed'] = 'La vostra subscripci ha estat cancellada';
$string['unsubscribeshort'] = 'Cancella subscripci';
$string['yesforever'] = 'S, per sempre';
$string['yesinitially'] = 'S, inicialment';
$string['youratedthis'] = 'La vostra valoraci';
$string['yournewtopic'] = 'Nou tema de debat';
$string['yourreply'] = 'La vostra resposta';

?>
